from setuptools import find_packages, setup

setup(
    name="superb-ai-apps",
    version="0.0.21",
    description="Python Package for Superb-AI Apps",
    install_requires=[
        "asttokens==2.4.1",
        "attrs==23.2.0",
        "backcall==0.2.0",
        "beautifulsoup4==4.12.3",
        "bleach==6.1.0",
        "certifi==2024.2.2",
        "charset-normalizer==3.3.2",
        "comm==0.2.2",
        "configparser==6.0.1",
        "debugpy==1.8.1",
        "decorator==5.1.1",
        "defusedxml==0.7.1",
        "directory-tree==0.0.4",
        "docopt==0.6.2",
        "exceptiongroup==1.2.0",
        "executing==2.0.1",
        "fastjsonschema==2.19.1",
        "gql==3.5.0",
        "graphql-core==3.2.4",
        "idna==3.6",
        "importlib_metadata==7.1.0",
        "ipykernel==6.29.4",
        "ipython==8.12.3",
        "jedi==0.19.1",
        "Jinja2==3.1.3",
        "jsonschema==4.21.1",
        "jsonschema-specifications==2023.12.1",
        "jupyter_client==8.6.1",
        "jupyter_core==5.7.2",
        "jupyterlab_pygments==0.3.0",
        "MarkupSafe==2.1.5",
        "matplotlib-inline==0.1.6",
        "mistune==3.0.2",
        "nbclient==0.10.0",
        "nbconvert==7.16.3",
        "nbformat==5.10.3",
        "nest-asyncio==1.6.0",
        "packaging==24.0",
        "pandocfilters==1.5.1",
        "parso==0.8.3",
        "pexpect==4.9.0",
        "phy_credit==0.9.0",
        "pickleshare==0.7.5",
        "pillow==10.3.0",
        "pipreqs==0.5.0",
        "platformdirs==4.2.0",
        "prompt-toolkit==3.0.43",
        "psutil==5.9.8",
        "ptyprocess==0.7.0",
        "pure-eval==0.2.2",
        "Pygments==2.17.2",
        "python-dateutil==2.9.0.post0",
        "pyzmq==25.1.2",
        "referencing==0.34.0",
        "requests==2.31.0",
        "requests-toolbelt==1.0.0",
        "rpds-py==0.18.0",
        "semver==3.0.2",
        "six==1.16.0",
        "soupsieve==2.5",
        "stack-data==0.6.3",
        "superb-ai-curate==1.4.0",
        "superb-ai-label==0.22.0",
        "tinycss2==1.2.1",
        "tornado==6.4",
        "traitlets==5.14.2",
        "typing_extensions==4.10.0",
        "urllib3==2.2.1",
        "wcwidth==0.2.13",
        "webencodings==0.5.1",
        "yarg==0.1.9",
        "zipfile-deflate64==0.2.0",
        "zipp==3.18.1",
        "natsort==8.4.0",
        "tqdm==4.66.4",
    ],
    packages=find_packages(exclude=("tests*", "testing*")),
)
